summaryrefslogtreecommitdiffstats
path: root/kugar/kudesigner/kudesigner_aboutdata.h
diff options
context:
space:
mode:
Diffstat (limited to 'kugar/kudesigner/kudesigner_aboutdata.h')
-rw-r--r--kugar/kudesigner/kudesigner_aboutdata.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kugar/kudesigner/kudesigner_aboutdata.h b/kugar/kudesigner/kudesigner_aboutdata.h
index 9be6a2de..b9682fde 100644
--- a/kugar/kudesigner/kudesigner_aboutdata.h
+++ b/kugar/kudesigner/kudesigner_aboutdata.h
@@ -27,14 +27,14 @@
static const char* description = I18N_NOOP( "GUI report template designer for Kugar report engine" );
static const char* version = KOFFICE_VERSION_STRING;
-KAboutData * newKudesignerAboutData()
+TDEAboutData * newKudesignerAboutData()
{
// Change this, of course
// The first argument of the KAboutData constructor is the instance name.
// It is very important, it's what's used for many things, like the subdir in share/apps, etc.
// It must also match the name of the application's .desktop file.
- KAboutData * aboutData = new KAboutData( "kudesigner", I18N_NOOP( "Kugar Report Designer" ),
- version, description, KAboutData::License_LGPL,
+ TDEAboutData * aboutData = new TDEAboutData( "kudesigner", I18N_NOOP( "Kugar Report Designer" ),
+ version, description, TDEAboutData::License_LGPL,
"(c) 2002,2003, Alexander Dymo (and the Kugar Team)" );
aboutData->addAuthor( "Alexander Dymo",
I18N_NOOP( "Maintainer, Report Designer, Kugar library enhancements" ),
@@ -27,14 +27,14 @@
{
// Change this, of course
- // The first argument of the KAboutData constructor is the instance name.
+ // The first argument of the TDEAboutData constructor is the instance name.
// It is very important, it's what's used for many things, like the subdir in share/apps, etc.
// It must also match the name of the application's .desktop file.